# If not provided by a system installed macro, define
%{!?__python2: %global __python2 /usr/bin/python2}
%{!?__python3: %global __python3 /usr/bin/python3}

%if %{_vendor} == "debbuild"
# Debian-specific custom flags for py3_install macro
%global pyinstflags --no-compile -O0
%global pytargetflags --install-layout=deb
%else
# Standard flags
%global pyinstflags -O1
%global pytargetflags %{nil}
%endif

%if 0%{?fedora} >= 30 || 0%{?rhel} >= 8 || 0%{?sle_version} >= 150100 || 0%{?suse_version} >= 1550
# Python 3 osc
%bcond_without python3
%else
# Python 2 osc
%bcond_with python3
%endif

%if %{with python3}
%{!?python3_pkgversion: %global python3_pkgversion 3}
%global python_pkgversion %{python3_pkgversion}
%global __python %{__python3}
%else
%global __python %{__python2}
%if 0%{?fedora} >= 28 || 0%{?suse_version} >= 1500
%global python_pkgversion 2
%else
%global python_pkgversion %{nil}
%endif
%endif

%{!?py_build: %global py_build CFLAGS="%{optflags}" %{__python} setup.py build}
%{!?py_install: %global py_install %{__python} setup.py install %{?pyinstflags} --skip-build --root %{buildroot} %{?pytargetflags}}

%if %{undefined python_sitelib} || 0%{?suse_version}
%global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")
%endif

# On Fedora 28+, enable the python distdeps generator for requires
# See https://fedoraproject.org/wiki/Changes/EnablingPythonGenerators
%{?python_enable_dependency_generator}

# User "--with devmode" on rpmbuild/debbuild to enable devmode
# like so: "debbuild -bb --with devmode obsctl.spec"
%bcond_with devmode


Name:           obsctl
Version:        0.5.0
Release:        1%{?dist}
Summary:        Unified high level interface for common actions with the Open Build Service
URL:            https://gitlab.datto.net/DevOps/obsctl
%if ! %{with devmode}
Source0:        %{name}-%{version}.tar.gz
%else
Source0:        %{name}.tar.gz
%endif
%if %{_vendor} == "debbuild" || %{_vendor} == "suse"
License:        GPL-2.0+
%else
License:        GPLv2+
%endif

%if %{_vendor} == "debbuild"
Packager:       Neal Gompa <ngompa@datto.com>
Group:          devel
%else
Group:          Development/Tools%{?suse_version:/Other}
%endif

BuildArch:      noarch

BuildRequires:  sed

%if %{_vendor} == "debbuild"
BuildRequires:  python%{python_pkgversion}-dev
BuildRequires:  python%{python_pkgversion}-wheel
%else
BuildRequires:  python%{python_pkgversion}-devel
%endif

BuildRequires:  python%{python_pkgversion}-setuptools
BuildRequires:  python%{python_pkgversion}-click
%if ! %{with python3}
# This is part of stdlib in Python 3
BuildRequires:  python%{python_pkgversion}-pathlib
%endif
BuildRequires:  python%{python_pkgversion}-lxml
%if (0%{?rhel} && 0%{?rhel} < 8) || (0%{?suse_version} && 0%{?suse_version} < 1500)
# Some older distributions used a different naming scheme for the package
BuildRequires:  rpm-python%{python_pkgversion}
%else
BuildRequires:  python%{python_pkgversion}-rpm
%endif
BuildRequires:  python%{python_pkgversion}-urlgrabber
BuildRequires:  osc

%if ! (%{defined python_enable_dependency_generator} || %{defined python_disable_dependency_generator})
Requires:       python%{python_pkgversion}-setuptools
Requires:       python%{python_pkgversion}-click
%if ! %{with python3}
# This is part of stdlib in Python 3
Requires:       python%{python_pkgversion}-pathlib
%endif
Requires:       python%{python_pkgversion}-lxml
%if (0%{?rhel} && 0%{?rhel} < 8) || (0%{?suse_version} && 0%{?suse_version} < 1500)
Requires:       rpm-python%{python_pkgversion}
%else
Requires:       python%{python_pkgversion}-rpm
%endif
Requires:       python%{python_pkgversion}-urlgrabber
%endif
Requires:       osc

# For the source services obsctl uses
# For specimport, tarimport, and scratchbuild
Requires:       obs-service-download_files
# For tarimport and scratchbuild
Requires:       obs-service-extract_file
# For scratchbuild
Requires:       obs-service-set_version

%description
This is a command line interface to simplify the packaging and deploy process
for packages built in the openSUSE Open Build Service. This utility functions
in a non-interactive manner allowing it to be utilized in continuous integration
and continuous deployment infrastructure.

%prep
%if ! %{with devmode}
%autosetup -n %{name}-%{version}
%else
%autosetup -n %{name}
%endif

%if (0%{?rhel} && 0%{?rhel} < 8) || (0%{?suse_version} && 0%{?suse_version} < 1500)
# rhel < 8 and suse < 15 lack support for environment markers :(
# we're building for python2 here anyway...
# NOTE: if we change to building for py3 only, we don't need this anymore
sed -e "s/; python_version < '3.4'//" -i setup.py
%endif

%if ! (0%{?fedora} >= 27 || 0%{?rhel} >= 8 || 0%{?suse_version} >= 1500)
# rpm did not have setuptools metadata in most distributions prior to rpm 4.14...
sed -e '/"rpm",/d' -i setup.py
%endif

%build
%py_build


%install
%py_install


mkdir -p %{buildroot}%{_sysconfdir}/obsctl
%if %{_vendor} != "debbuild"
touch %{buildroot}%{_sysconfdir}/obsctl/obsauth.json
%endif

%if %{_vendor} == "debbuild"
touch %{buildroot}%{_sysconfdir}/obsctl/.keep
%endif

%files
%license COPYING
%dir %{_sysconfdir}/obsctl
%if %{_vendor} == "debbuild"
%{_sysconfdir}/obsctl/.keep
%else
%ghost %{_sysconfdir}/obsctl/obsauth.json
%endif
%{_bindir}/obsctl
%{python_sitelib}/obsctl-*.egg-info
%{python_sitelib}/obsctl

%if %{_vendor} == "debbuild"
%post
# Do late-stage bytecompilation, per debian policy
pycompile -p %{name} -V -3.0

%preun
# Ensure all __pycache__ files are deleted, per debian policy
pyclean -p %{name}
%endif


%changelog
* Tue Dec 03 2019 Neal Gompa <ngompa@datto.com> - 0.5.0
- Ensure that --repo-name switch is marked as required in all subcommands
- specimport: Add support for fetching Dist-Git resources automatically
- scratchbuild: Add support for building from Package SCM repositories
- Misc internal API changes to support new Package SCM functionality

* Sat Mar 30 2019 Neal Gompa <ngompa@datto.com> - 0.4.2
- scratchbuild: Add with/without flags to toggle build features

* Thu Mar 28 2019 Neal Gompa <ngompa@datto.com> - 0.4.1
- Fix sed expression to fix Python metadata for EL7 builds
- Adjust black to format to 100 columns per line

* Tue Mar 26 2019 Neal Gompa <ngompa@datto.com> - 0.4.0
- Python 3 support for Fedora 30+
- Code is now formatted using 'black'
- Misc internal API changes to address pylint issues

* Wed Nov 07 2018 Neal Gompa <ngompa@datto.com> - 0.3.14
- Fix timestamp format for snapshot versions

* Wed Oct 24 2018 Neal Gompa <ngompa@datto.com> - 0.3.13
- Implement version match check for tarimport

* Mon Aug 27 2018 Neal Gompa <ngompa@datto.com> - 0.3.12
- scratchbuild: Add '--local-package' switch to 'osc build' invocation
- scratchbuild: Clean up success and failure exit messaging

* Wed Feb 28 2018 Neal Gompa <ngompa@datto.com> - 0.3.11
- Allow 'prerel-upver' for snapshot version form

* Tue Jan 23 2018 Neal Gompa <ngompa@datto.com> - 0.3.10
- Further sanitize the branch names to prevent unexpected breakages

* Thu Dec 14 2017 Neal Gompa <ngompa@datto.com> - 0.3.9
- Fix prerel spec version generation

* Tue Dec 12 2017 Neal Gompa <ngompa@datto.com> - 0.3.8
- Fix pattern match for generated _service in tarimport

* Tue Dec 12 2017 Neal Gompa <ngompa@datto.com> - 0.3.7
- Fill in the setuptools metadata
- scratchbuild, tarimport: Add option to set non-default path to extract spec file

* Fri Dec 08 2017 Neal Gompa <ngompa@datto.com> - 0.3.6
- Revert scratchbuild changes in 0.3.4 and 0.3.5

* Fri Dec 08 2017 Neal Gompa <ngompa@datto.com> - 0.3.5
- scratchbuild: Use restricted matching for generated directory

* Fri Dec 08 2017 Neal Gompa <ngompa@datto.com> - 0.3.4
- Print out where people can see the OBS build for obsimport commands
- scratchbuild: Use exact name of the generated directory for spec extraction

* Thu Nov 30 2017 Neal Gompa <ngompa@datto.com> - 0.3.3
- Add download_files service support to scratchbuild

* Thu Nov 30 2017 Neal Gompa <ngompa@datto.com> - 0.3.2
- Add download_files service support to tarimport

* Wed Nov 29 2017 Neal Gompa <ngompa@datto.com> - 0.3.1
- Fix _service file existence check in dscimport

* Wed Nov 29 2017 Neal Gompa <ngompa@datto.com> - 0.3.0
- Implement dscimport for dsc packaging repos

* Tue Nov 28 2017 Neal Gompa <ngompa@datto.com> - 0.2.10
- Add explicit dependencies for required OBS source services
- Ensure scratchbuild ignores hidden files (dotfiles)

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.9
- Refactor scratchbuild to not require checkout of OBS package

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.8
- Add missing import for os to tarimport

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.7
- Remove accidental superfluous delete command

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.6
- Fix tarimport and tarball creation logic

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.5
- Mark '--source-file' as a required arg for scratchbuild and tarimport

* Wed Nov 22 2017 Neal Gompa <ngompa@datto.com> - 0.2.4
- The scratchbuild command now requires a path to an existing tarball
- Librarized the tarball regeneration logic into new internal tar lib
- Fix osc config generation to keep tempfile for the whole run

* Tue Nov 21 2017 Neal Gompa <ngompa@datto.com> - 0.2.3
- Bump version

* Tue Nov 21 2017 Neal Gompa <ngompa@datto.com> - 0.2.2
- Add missing runtime dependency on setuptools for obsctl executable

* Tue Nov 21 2017 Neal Gompa <ngompa@datto.com> - 0.2.1
- Add initial spec internal library module
- Unify logic in scratchbuild and {tar,spec}import commands
- Make the CLI arguments consistent across commands

* Thu Nov 16 2017 Neal Gompa <ngompa@datto.com> - 0.2.0
- Rename tarsrc-obsimport to tarimport
- Implement specimport for spec+patches repos
- Make tarimport and specimport use the same releasing code in obsc library
- Fix python2_pkgversion conditional in spec for Fedora 27

* Wed Nov 15 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.9
- Bump version

* Wed Nov 15 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.8
- Bump version

* Wed Nov 15 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.7
- Fix tarsrc_obsimport script

* Tue Nov 14 2017 Neal Gompa <ngompa@datto.com> - 0.1.6
- Reword one of the options to match the original script

* Tue Nov 14 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.5
- bump version with addition of CI

* Mon Nov 13 2017 Neal Gompa <ngompa@datto.com> - 0.1.4
- Fix local definition of python2_sitelib

* Mon Nov 13 2017 Neal Gompa <ngompa@datto.com> - 0.1.3
- Consistently use python2_pkgversion macro in spec
- Fix ghost file entry typo
- Add bobs and bits to make openSUSE builds happy

* Mon Nov 13 2017 Neal Gompa <ngompa@datto.com> - 0.1.2
- Revise build-time dependencies to be cross-distribution
- Add missing runtime dependencies
- Wrap the description correctly

* Mon Nov 13 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.1
- Add ghost configuration file for auth information

* Fri Nov 10 2017 Mark Bluemer <mbluemer@datto.com> - 0.1.0
- Inital Packaging

